### Detailed Activity Analysis of Chat Participants _( by minute )_
In previous section, I tried to find out how users are spending their time in Chat(s), which we're analyzing, by splitting the whole day into **8** equal parts.

Time for some detailed investigation ... :wink:

Here I'm going to split whole day into 4 equal parts and draw 4 subplots, where I'll try to depict how a user spent each minute of his/ her day _( 1440 minutes in a day )_ over this period of time _( for which we've Chat record )_, in this Chat.

It'll be helpful in understanding, when this user is generally more or less active _( i.e. activity patterns / sleep patterns )_, depending upon what we're observing for this period of time.

No doubt you've already understood, if you had a very long Private Chat with a person or a high traffic group, consider analyzing that Chat file, you'll be happy to learn much more about those participating peoples.

So I applied `util.plotActivityOfUserByMinute()` on a collection of messages from each Participants of Chat _( both Private & Group )_, and result was really interesting.

Check them out.

#### For Private Chat :
1.

![detailedActivityOfParticipantOne](../plots/detailedActivityOf*******oyInPrivateChatByMinute.svg)
2.

![detailedActivityOfParticipantTwo](../plots/detailedActivityOf******************atty_\)InPrivateChatByMinute.svg)

#### For Group Chat :
1.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************SS\)InGroupChatByMinute.svg)
2.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************597InGroupChatByMinute.svg)
3.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************377InGroupChatByMinute.svg)
4.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************965InGroupChatByMinute.svg)
5.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************316InGroupChatByMinute.svg)
6.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************895InGroupChatByMinute.svg)
7.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************494InGroupChatByMinute.svg)
8.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************013InGroupChatByMinute.svg)
9.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf*************CSS\)InGroupChatByMinute.svg)
10.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf**********749InGroupChatByMinute.svg)
11.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************858InGroupChatByMinute.svg)
12.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf*********SS\)InGroupChatByMinute.svg)
13.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************537InGroupChatByMinute.svg)
14.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************334InGroupChatByMinute.svg)
15.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************422InGroupChatByMinute.svg)
16.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************058InGroupChatByMinute.svg)
17.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf*************8347InGroupChatByMinute.svg)
18.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************456InGroupChatByMinute.svg)
19.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************4775InGroupChatByMinute.svg)
20.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************181InGroupChatByMinute.svg)
21.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************691InGroupChatByMinute.svg)
22.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************459InGroupChatByMinute.svg)
23.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************093InGroupChatByMinute.svg)
24.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************979InGroupChatByMinute.svg)
25.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************697InGroupChatByMinute.svg)
26.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************183InGroupChatByMinute.svg)
27.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************502InGroupChatByMinute.svg)
28.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************606InGroupChatByMinute.svg)
29.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf*******oyInGroupChatByMinute.svg)
30.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************849InGroupChatByMinute.svg)
31.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************116InGroupChatByMinute.svg)
32.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************CSS\)InGroupChatByMinute.svg)
33.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************421InGroupChatByMinute.svg)
34.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************848InGroupChatByMinute.svg)
35.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************963InGroupChatByMinute.svg)
36.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************2_78InGroupChatByMinute.svg)
37.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************051InGroupChatByMinute.svg)
38.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf*********S\)InGroupChatByMinute.svg)
39.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************454InGroupChatByMinute.svg)
40.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************877InGroupChatByMinute.svg)
41.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************592InGroupChatByMinute.svg)
42.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************203InGroupChatByMinute.svg)
43.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************425InGroupChatByMinute.svg)
44.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************382InGroupChatByMinute.svg)
45.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf************669InGroupChatByMinute.svg)
